==> commerce_culqi-2.0.1.tar.gz: commerce_culqi/src/Service/CulqiService.php <==
<?php

namespace Drupal\commerce_culqi\Service;

use Culqi\Culqi;
use Culqi\Error\InvalidApiKey;
use Drupal\commerce_culqi\Charge;
use Drupal\commerce_payment\Entity\PaymentInterface;
use Drupal\commerce_payment\Exception\PaymentGatewayException;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\ParameterBag;

/**
 * Culqi utility service.
 */
class CulqiService {

  /**
   * Culqi API client.
   *
   * @var \Culqi\Culqi
   */
  protected $api;

  /**
   * Culqi payment gateway plugin config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Default logger.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * CulqiService constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   Config factory.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $loggerFactory
   *   Logger factor.
   */
  public function __construct(ConfigFactoryInterface $configFactory, LoggerChannelFactoryInterface $loggerFactory) {
    $this->config = $configFactory->get('commerce_payment.commerce_payment_gateway.culqi');
    $this->logger = $loggerFactory->get('commerce_culqi');
  }

  /**
   * Preform server side charge request.
   *
   * @param \Symfony\Component\HttpFoundation\ParameterBag $parameterBag
   *   Request parameters.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   Json response.
   */
  public function createCharge(ParameterBag $parameterBag) {
    try {
      $apiResponse = $this->getApi()->Charges->create(
        [
          "amount" => $parameterBag->get('amount'),
          "capture" => TRUE,
          "currency_code" => $parameterBag->get('currency_code'),
          "email" => $parameterBag->get('email'),
          "source_id" => $parameterBag->get('source_id'),
          "antifraud_details" => [
            "first_name" => $parameterBag->get('first_name', 'NA'),
            "last_name" => $parameterBag->get('last_name', 'NA'),
            "address" => $parameterBag->get('address', 'NA'),
            "address_city" => $parameterBag->get('city', 'NA'),
            "country_code" => $parameterBag->get('country_code', 'NA'),
          ],
        ]
      );

      $charge = Charge::fromObject($apiResponse);
    }
    catch (\Exception $exception) {
      $charge = Charge::isInvalid();
      $this->logger->error($exception->getMessage());
    }

    return new JsonResponse($charge);
  }

  /**
   * Preform server side refund request.
   *
   * @param \Drupal\commerce_payment\Entity\PaymentInterface $payment
   *   The payment to action refund for.
   * @param string $amount
   *   Refund amount.
   * @param string $reason
   *   Reason for refund, must be one of supported reasons.
   */
  public function createRefund(PaymentInterface $payment, $amount = NULL, $reason = 'solicitud_comprador') {
    try {
      $this->getApi()->Refunds->create(
        [
          "amount" => $amount,
          "charge_id" => $payment->getRemoteId(),
          "reason" => $reason,
        ]
      );
    }
    catch (\Exception $exception) {
      $this->logger->error($exception->getMessage());
      throw new PaymentGatewayException($exception->getMessage());
    }
  }

  /**
   * Validate charge.
   *
   * @param string $remoteId
   *   The remote charge ID.
   *
   * @return object
   *   Charge data.
   */
  public function validateCharge($remoteId) {
    $this->logger->error(print_r($this->getApi()->Charges->get($remoteId), 1));
    return $this->getApi()->Charges->get($remoteId);
  }

  /**
   * Get api client.
   *
   * @return \Culqi\Culqi
   *   Culqi API client.
   */
  public function getApi() {
    if ($this->api instanceof Culqi) {
      return $this->api;
    }

    try {
      $options = ['api_key' => $this->config->get('configuration.secret_key')];

      $api = new Culqi($options);
      $this->api = $api;
    }
    catch (InvalidApiKey $exception) {
      $this->logger->critical($exception->getMessage());
    }

    return $this->api;
  }

}

==> commerce_culqi-2.0.2.tar.gz: commerce_culqi/src/Service/CulqiService.php <==
<?php

namespace Drupal\commerce_culqi\Service;

use Culqi\Culqi;
use Culqi\Error\InvalidApiKey;
use Drupal\commerce_culqi\Charge;
use Drupal\commerce_payment\Entity\PaymentInterface;
use Drupal\commerce_payment\Exception\PaymentGatewayException;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\ParameterBag;

/**
 * Culqi utility service.
 */
class CulqiService {

  /**
   * Culqi API client.
   *
   * @var \Culqi\Culqi
   */
  protected $api;

  /**
   * Culqi payment gateway plugin config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Default logger.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * CulqiService constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   Config factory.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $loggerFactory
   *   Logger factor.
   */
  public function __construct(ConfigFactoryInterface $configFactory, LoggerChannelFactoryInterface $loggerFactory) {
    $this->config = $configFactory;
    $this->logger = $loggerFactory->get('commerce_culqi');
  }

  /**
   * Preform server side charge request.
   *
   * @param \Symfony\Component\HttpFoundation\ParameterBag $parameterBag
   *   Request parameters.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   Json response.
   */
  public function createCharge(ParameterBag $parameterBag) {
    try {
      $currentPaymentGateway = $parameterBag->get('current_payment_gateway');
      $keyConfig = 'commerce_payment.commerce_payment_gateway.' . $currentPaymentGateway;
      $this->config = $this->config->get($keyConfig);

      $apiResponse = $this->getApi()->Charges->create(
        [
          "amount" => $parameterBag->get('amount'),
          "capture" => TRUE,
          "currency_code" => $parameterBag->get('currency_code'),
          "email" => $parameterBag->get('email'),
          "source_id" => $parameterBag->get('source_id'),
          "antifraud_details" => [
            "first_name" => $parameterBag->get('first_name', 'NA'),
            "last_name" => $parameterBag->get('last_name', 'NA'),
            "address" => $parameterBag->get('address', 'NA'),
            "address_city" => $parameterBag->get('city', 'NA'),
            "country_code" => $parameterBag->get('country_code', 'NA'),
          ],
        ]
      );

      $charge = Charge::fromObject($apiResponse);
    }
    catch (\Exception $exception) {
      $charge = Charge::isInvalid();
      $this->logger->error($exception->getMessage());
    }

    return new JsonResponse($charge);
  }

  /**
   * Preform server side refund request.
   *
   * @param \Drupal\commerce_payment\Entity\PaymentInterface $payment
   *   The payment to action refund for.
   * @param string $amount
   *   Refund amount.
   * @param string $reason
   *   Reason for refund, must be one of supported reasons.
   */
  public function createRefund(PaymentInterface $payment, $amount = NULL, $reason = 'solicitud_comprador') {
    try {
      $this->getApi()->Refunds->create(
        [
          "amount" => $amount,
          "charge_id" => $payment->getRemoteId(),
          "reason" => $reason,
        ]
      );
    }
    catch (\Exception $exception) {
      $this->logger->error($exception->getMessage());
      throw new PaymentGatewayException($exception->getMessage());
    }
  }

  /**
   * Validate charge.
   *
   * @param string $remoteId
   *   The remote charge ID.
   *
   * @return object
   *   Charge data.
   */
  public function validateCharge($remoteId) {
    $this->logger->error(print_r($this->getApi()->Charges->get($remoteId), 1));
    return $this->getApi()->Charges->get($remoteId);
  }

  /**
   * Get api client.
   *
   * @return \Culqi\Culqi
   *   Culqi API client.
   */
  public function getApi() {
    if ($this->api instanceof Culqi) {
      return $this->api;
    }

    try {
      $options = ['api_key' => $this->config->get('configuration.secret_key')];

      $api = new Culqi($options);
      $this->api = $api;
    }
    catch (InvalidApiKey $exception) {
      $this->logger->critical($exception->getMessage());
    }

    return $this->api;
  }

}
